GameDataTable

Enum GameDataTable 

#[non_exhaustive]
#[repr(u8)]
pub enum GameDataTable {
Show 67 variants Spells = 0, Traits = 1, ExpansionTraits = 2, Items = 3, Specs = 4, Classes = 5, GlobalColors = 6, GlobalStrings = 7, ItemBonuses = 8, Curves = 9, CurvePoints = 10, RandPropPoints = 11, ItemScalingConfigs = 12, ItemOffsetCurves = 13, ItemSquishEras = 14, Enchantments = 15, GemProperties = 16, ItemDamageScaling = 17, CooldownSets = 18, ExpectedStats = 19, ExpectedStatMods = 20, SpecializationSpells = 21, RacialSpells = 22, PowerTypes = 23, ItemArmorQuality = 24, ItemArmorShield = 25, ItemArmorTotal = 26, ArmorLocation = 27, JournalTiers = 28, JournalInstances = 29, CraftedProducts = 30, Professions = 31, PvpSeasons = 32, PvpTiers = 33, MythicPlusSeasons = 34, Difficulties = 35, ItemDropScaling = 36, Currencies = 37, CurrencyCategories = 38, ItemBonusListGroups = 39, ItemGroupIlvlScalingEntries = 40, ItemLevelSelectors = 41, ItemLevelSelectorQualitySets = 42, ItemLevelSelectorQualities = 43, ItemConversions = 44, ChallengeModeItemBonusOverrides = 45, ItemBonusSequenceSpells = 46, DelvesSeasons = 47, HpPerSta = 48, CombatRatings = 49, CombatRatingsMultByIlvl = 50, StaminaMultByIlvl = 51, BaseMp = 52, SpellScaling = 53, ArmorMitigationByLvl = 54, NpcTotalHp = 55, NpcDamageByClass = 56, ChallengeModeHealth = 57, ChallengeModeDamage = 58, ItemSocketCostPerLevel = 59, ProfessionRatings = 60, BaseProfessionRatings = 61, Creatures = 62, CreatureDifficulties = 63, ContentTunings = 64, ContentTuningXDifficulty = 65, ContentTuningXExpected = 66,
}
Stable identity for a synchronized game-data table.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Spells = 0



Traits = 1



ExpansionTraits = 2



Items = 3



Specs = 4



Classes = 5



GlobalColors = 6



GlobalStrings = 7



ItemBonuses = 8



Curves = 9



CurvePoints = 10



RandPropPoints = 11



ItemScalingConfigs = 12



ItemOffsetCurves = 13



ItemSquishEras = 14



Enchantments = 15



GemProperties = 16



ItemDamageScaling = 17



CooldownSets = 18



ExpectedStats = 19



ExpectedStatMods = 20



SpecializationSpells = 21



RacialSpells = 22



PowerTypes = 23



ItemArmorQuality = 24



ItemArmorShield = 25



ItemArmorTotal = 26



ArmorLocation = 27



JournalTiers = 28



JournalInstances = 29



CraftedProducts = 30



Professions = 31



PvpSeasons = 32



PvpTiers = 33



MythicPlusSeasons = 34



Difficulties = 35



ItemDropScaling = 36



Currencies = 37



CurrencyCategories = 38



ItemBonusListGroups = 39



ItemGroupIlvlScalingEntries = 40



ItemLevelSelectors = 41



ItemLevelSelectorQualitySets = 42



ItemLevelSelectorQualities = 43



ItemConversions = 44



ChallengeModeItemBonusOverrides = 45



ItemBonusSequenceSpells = 46



DelvesSeasons = 47



HpPerSta = 48



CombatRatings = 49



CombatRatingsMultByIlvl = 50



StaminaMultByIlvl = 51



BaseMp = 52



SpellScaling = 53



ArmorMitigationByLvl = 54



NpcTotalHp = 55



NpcDamageByClass = 56



ChallengeModeHealth = 57



ChallengeModeDamage = 58



ItemSocketCostPerLevel = 59



ProfessionRatings = 60



BaseProfessionRatings = 61



Creatures = 62



CreatureDifficulties = 63



ContentTunings = 64



ContentTuningXDifficulty = 65



ContentTuningXExpected = 66

Implementations

Source

impl GameDataTable

pub const COUNT: usize = <Self as EnumCount>::COUNT

Number of canonical synchronized tables.

pub fn iter() -> impl ExactSizeIterator<Item = Self>

Iterates over every canonical table in registry order.

pub fn name(self) -> &'static str

Returns the stable snake-case registry and reporting name.

pub fn command_name(self) -> &'static str

Returns the stable kebab-case command-line argument name.

pub const fn metadata(self) -> &'static GameDataTableMetadata

Returns this table’s canonical storage and exposure metadata.

pub const fn database_name(self) -> &'static str

Returns the fully qualified PostgreSQL table name.

pub const fn snapshot_key(self) -> &'static [&'static str]

Returns the ordered columns that uniquely identify a snapshot row.

pub const fn is_snapshot_exposed(self) -> bool

Reports whether the table is included in published Studio snapshots.

pub const fn is_mcp_exposed(self) -> bool

Reports whether the table must have an MCP query descriptor.